package com.example.survey.controller;

import com.example.survey.dto.metaData.CreateMetaDataDTO;
import com.example.survey.dto.metaData.DeleteMetaDataDTO;
import com.example.survey.dto.metaData.ModifyMetaDataDTO;
import com.example.survey.enumeration.ResultEnum;
import com.example.survey.service.MetaDataService;
import com.example.survey.vo.ResultVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Pope
 */
@RestController
@RequestMapping("/metaData")
public class MetaDataController {

    @Autowired
    MetaDataService metaDataService;

    @PostMapping("/metaData")
    public ResultVO createMetaData(@RequestBody CreateMetaDataDTO createMetaDataDTO){
        metaDataService.createMetaData(createMetaDataDTO);
        return new ResultVO(ResultEnum.SUCCESS);
    }

    @GetMapping("/nameList")
    public ResultVO listMetaData(@RequestParam(value = "name",required = false) String name,
                                @RequestParam("currentPage")int currentPage,
                                @RequestParam(value = "pageSize",defaultValue = "30")int pageSize){
        Map<String, Object> resultMap = new HashMap<>(16,0.75F);
        resultMap.put("totalCount", metaDataService.countMetaData(name));
        resultMap.put("currentPage", currentPage);
        resultMap.put("pageSize", pageSize);
        resultMap.put("data", metaDataService.listMetaDataNameLimit(name,currentPage,pageSize));

        ResultVO resultVO = new ResultVO(ResultEnum.SUCCESS);
        resultVO.setData(resultMap);
        return resultVO;
    }

    @PutMapping("/metaData")
    public ResultVO modifyMetaData(@RequestBody ModifyMetaDataDTO modifyMetaDataDTO){
        metaDataService.modifyMetaData(modifyMetaDataDTO);
        return new ResultVO(ResultEnum.SUCCESS);
    }

    @GetMapping("/metaData")
    public ResultVO getMetaData(@RequestParam("name")String name){
        ResultVO resultVO = new ResultVO();
        resultVO.setData(metaDataService.getMetaData(name));
        return resultVO;
    }

    @DeleteMapping("/metaData")
    public ResultVO deleteMetaData(@RequestBody DeleteMetaDataDTO deleteMetaDataDTO){
        metaDataService.deleteMetaData(deleteMetaDataDTO);
        return new ResultVO(ResultEnum.SUCCESS);
    }

    @PostMapping("/wordTemplate")
    public ResultVO bindWordTemplate(@RequestParam("template")MultipartFile template,
                                     @RequestParam("name")String name){
        metaDataService.bindWordTemplate(template,name);
        return new ResultVO(ResultEnum.SUCCESS);
    }

}
