package com.example.survey.controller;

import com.example.survey.dto.project.CreateProjectDTO;
import com.example.survey.dto.project.ModifyProjectDTO;
import com.example.survey.dto.project.ModifyStateDTO;
import com.example.survey.enumeration.RespondentStateEnum;
import com.example.survey.enumeration.ResultEnum;
import com.example.survey.service.ProjectService;
import com.example.survey.vo.ProjectVO;
import com.example.survey.vo.ResultVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Pope
 */
@RestController
@RequestMapping("/project")
public class ProjectController {

    @Autowired
    ProjectService projectService;


    @PostMapping("/project")
    public ResultVO createProject(@RequestBody CreateProjectDTO createProjectDTO) {
        projectService.createProject(createProjectDTO);
        return new ResultVO(ResultEnum.SUCCESS);
    }

    @GetMapping("/projectList")
    public ResultVO getProject(@RequestParam(value = "name",required = false) String name,
                               @RequestParam(value = "state", required = false)String state,
                               @RequestParam(value = "currentPage") int currentPage,
                               @RequestParam(value = "pageSize", defaultValue = "30") int pageSize) {
        Map<String, Object> resultMap = new HashMap<>(16,0.75F);
        resultMap.put("totalCount", projectService.countProject(name,state));
        resultMap.put("currentPage", currentPage);
        resultMap.put("pageSize", pageSize);
        resultMap.put("data", projectService.listProjectLimit(name,state, currentPage, pageSize));
        ResultVO resultVO = new ResultVO(ResultEnum.SUCCESS);
        resultVO.setData(resultMap);
        return resultVO;
    }

    @GetMapping("/respondentCount")
    public ResultVO getRespondentCount(@RequestParam(value = "name") String name) {

        Map<String, Object> resultMap = new HashMap<>(16, 0.75F);
        resultMap.put("respondentCount", projectService.countRespondent(name));
        resultMap.put("notInvestigatedRespondentCount", projectService.countRespondent(name, RespondentStateEnum.NOT_INVESTIGATED.getValue()));

        ResultVO resultVO = new ResultVO(ResultEnum.SUCCESS);
        resultVO.setData(resultMap);
        return resultVO;
    }

    @PutMapping("/projectState")
    public ResultVO modifyProjectState(@RequestBody ModifyStateDTO modifyStateDTO){
        projectService.modifyProjectState(modifyStateDTO);
        return new ResultVO(ResultEnum.SUCCESS);
    }

    @PutMapping("/project")
    public ResultVO modifyProject(@RequestBody ModifyProjectDTO modifyProjectDTO){
        projectService.modifyProject(modifyProjectDTO);
        return new ResultVO(ResultEnum.SUCCESS);
    }

}
