package com.example.survey.dao;

import com.example.survey.entity.Project;
import com.example.survey.entity.Record;
import com.example.survey.entity.Respondent;
import com.example.survey.entity.User;

import java.util.List;

/**
 * @author Pope
 */
public interface RecordDao {
    /**
     * 判断是否存在符合条件的流调记录
     *
     * @param respondent 调查对象
     * @param project 项目
     * @param state      流调记录状态
     * @return 是否存在符合条件的流调记录
     */
    boolean existRecord(Respondent respondent, Project project, String state);

    /**
     * 根据调查对象身份证号与流调记录状态查询流调记录
     *
     * @param respondent 调查对象
     * @param project 项目
     * @param state      流调记录状态
     * @return 流调记录
     */
    Record getRecord(Respondent respondent,Project project, String state);

    /**
     * 保存流调记录，若已有相同id的则更新
     *
     * @param record 流调记录
     */
    void saveRecord(Record record);

    /**
     * 根据筛选条件查询流调记录数量
     *
     * @param respondent 调查对象
     * @param user 分配的人员
     * @param project 项目
     * @param state 流调记录状态
     * @param version 流调记录版本
     * @param questionnaireNumber 问卷编号
     * @return 数量
     */
    long countRecord(Respondent respondent, User user, Project project, String state, String version, String questionnaireNumber);

    /**
     * 根据筛选条件分页查询流调记录
     *
     * @param respondent 调查对象
     * @param user 分配的人员
     * @param project 项目
     * @param state 流调记录状态
     * @param version 流调记录版本
     * @param questionnaireNumber 问卷编号
     * @param offset 偏移量
     * @param pageSize 页大小
     * @return 流调记录
     */
    List<Record> listRecordLimit(Respondent respondent, User user, Project project, String state, String version, String questionnaireNumber, int offset, int pageSize);

    /**
     * 根据筛选条件查询流调记录
     *
     * @param respondent 调查对象
     * @param project 项目
     * @param version 版本号
     * @return 流调记录
     */
    Record selectRecord(Respondent respondent, Project project, String version);

    /**
     * 根据筛选条件查询流调记录
     *
     * @param respondent 调查对象
     * @param project 项目
     * @param states 记录状态
     * @return 流调记录
     */
    Record selectRecord(Respondent respondent, Project project, List<String> states);

    /**
     * 查询流调记录列表
     *
     * @param project 项目
     * @param respondent 调查对象
     * @return 流调记录列表
     */
    List<Record> listRecord(Project project, Respondent respondent);
}
