package com.example.survey.dao;

import com.example.survey.entity.Project;
import com.example.survey.entity.Respondent;
import com.example.survey.entity.User;

import java.util.List;

/**
 * @author Pope
 */
public interface RespondentDao {
    /**
     * 插入待调查对象
     *
     * @param respondent 待调查对象
     */
    void saveRespondent(Respondent respondent);

    /**
     * 根据流调人员电话号码分页查询待调查对象列表
     *
     * @param user     分配的人员
     * @param state    状态
     * @param idNumber 身份证号
     * @param name     调查对象姓名
     * @param phone    调查对象电话
     * @param province 省份
     * @param city     城市
     * @param county   区县
     * @param project  项目
     * @param offset   偏移量
     * @param pageSize 大小
     * @return 待调查对象列表
     */
    List<Respondent> listRespondentLimit(User user, String state, String idNumber, String name, String phone, String province, String city, String county, Project project, int offset, int pageSize);

    /**
     * 判断是否存在对应id的调查对象
     *
     * @param idNumber 身份证号
     * @param project  项目
     * @return 是否存在该调查对象
     */
    boolean existRespondent(String idNumber, Project project);

    /**
     * 判断是否存在符合条件的调查对象
     *
     * @param idNumber 身份证号
     * @param project  项目
     * @param state    调查对象状态
     * @return 是否存在该调查对象
     */
    boolean existRespondent(String idNumber, Project project, String state);

    /**
     * 根绝筛选条件获取调查对象数量
     *
     * @param user     分配的人员
     * @param state    状态
     * @param idNumber 身份证号
     * @param name     调查对象姓名
     * @param phone    调查对象电话
     * @param province 省份
     * @param city     城市
     * @param county   区县
     * @param project  项目
     * @return 数量
     */
    long countRespondent(User user, String state, String idNumber, String name, String phone, String province, String city, String county, Project project);


    /**
     * 根据身份证号查询调查对象
     *
     * @param idNumber 身份证号
     * @param project  项目
     * @return 调查对象
     */
    Respondent selectRespondent(String idNumber, Project project);

    /**
     * 删除调查对象
     *
     * @param idNumber 身份证号
     */
    void deleteRespondent(String idNumber);


    /**
     * 根据项目与调查对象状态查询调查对象数量
     *
     * @param project 项目
     * @param state   调查对象状态
     * @return 调查对象数量
     */
    long countRespondent(Project project, String state);


}
