package com.example.survey.dao.impl;

import com.example.survey.dao.RespondentDao;
import com.example.survey.entity.Project;
import com.example.survey.entity.Respondent;
import com.example.survey.entity.User;
import com.example.survey.enumeration.ResultEnum;
import com.example.survey.exception.RespondentException;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * @author Pope
 */
@Log4j2
@Repository
public class RespondentDaoImpl implements RespondentDao {

    @Autowired
    private MongoTemplate mongoTemplate;

    @Override
    public void saveRespondent(Respondent respondent) {
        try {
            mongoTemplate.save(respondent);
        } catch (Exception e) {
            throw new RespondentException(ResultEnum.ALREADY_EXIST_RESPONDENT);
        }
    }

    @Override
    public List<Respondent> listRespondentLimit(User user, String state, String idNumber, String name, String phone, String province, String city, String county, Project project, int offset, int pageSize) {
        Criteria criteria = new Criteria();

        if (idNumber != null) {
            criteria.and("idNumber").is(idNumber);
        }
        if (name != null) {
            criteria.and("name").regex(name);
        }
        if (phone != null) {
            criteria.and("phone").is(phone);
        }

        if (province != null) {
            criteria.and("administrativeArea.province").is(province);
        }
        if (city != null) {
            criteria.and("administrativeArea.city").is(city);
        }
        if (county != null) {
            criteria.and("administrativeArea.county").is(county);
        }
        if (project != null) {
            criteria.and("project.$id").is(project.getId());
        }
        if (user != null) {
            criteria.and("user.$id").is(user.getId());
        }
        if (state != null) {
            criteria.and("state").is(state);
        }

        Query query = new Query(criteria).skip(offset).limit(pageSize);
        return mongoTemplate.find(query, Respondent.class);
    }

    @Override
    public long countRespondent(User user, String state, String idNumber, String name, String phone, String province, String city, String county, Project project) {
        Criteria criteria = new Criteria();

        if (idNumber != null) {
            criteria.and("idNumber").is(idNumber);
        }
        if (name != null) {
            criteria.and("name").regex(name);
        }
        if (phone != null) {
            criteria.and("phone").is(phone);
        }

        if (province != null) {
            criteria.and("administrativeArea.province").is(province);
        }
        if (city != null) {
            criteria.and("administrativeArea.city").is(city);
        }
        if (county != null) {
            criteria.and("administrativeArea.county").is(county);
        }
        if (project != null) {
            criteria.and("project.$id").is(project.getId());
        }
        if (user != null) {
            criteria.and("user.$id").is(user.getId());
        }
        if (state != null) {
            criteria.and("state").is(state);
        }

        Query query = new Query(criteria);
        return mongoTemplate.count(query, Respondent.class);
    }

    @Override
    public boolean existRespondent(String idNumber, Project project) {
        Criteria criteria = Criteria.where("idNumber").is(idNumber);
        if (project != null) {
            criteria.and("project.$id").is(project.getId());
        }
        Query query = new Query(criteria);

        return mongoTemplate.exists(query, Respondent.class);
    }

    @Override
    public boolean existRespondent(String idNumber, Project project, String state) {
        Query query = new Query(
                Criteria.where("idNumber").is(idNumber)
                        .and("project.$id").is(project.getId())
                        .and("state").is(state));
        return mongoTemplate.exists(query, Respondent.class);
    }


    @Override
    public Respondent selectRespondent(String idNumber, Project project) {
        Query query = new Query(Criteria.where("idNumber").is(idNumber).and("project.$id").is(project.getId()));
        return mongoTemplate.findOne(query, Respondent.class);
    }

    @Override
    public void deleteRespondent(String idNumber) {
        Query query = new Query(Criteria.where("idNumber").is(idNumber));
        mongoTemplate.remove(query, Respondent.class);
    }

    @Override
    public long countRespondent(Project project, String state) {
        Criteria criteria = Criteria.where("project.$id").is(project.getId()).and("state").is(state);
        Query query = new Query(criteria);
        return mongoTemplate.count(query, Respondent.class);
    }


}
