package com.example.survey.entity;

import com.example.survey.entity.inner.AdministrativeArea;
import com.example.survey.entity.inner.ProjectPart;
import lombok.*;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.DBRef;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Set;

/**
 * @author Pope
 * 调查对象表
 */
@Data
@Document(collection = "respondent")
@CompoundIndexes({
        @CompoundIndex(name = "unique",def = "{idNumber : 1, project : 1}",unique = true)
})
public class Respondent {

    /**
     * id
     */
    @Id
    private ObjectId id;

    /**
     * 身份证号
     */
    private String idNumber;

    /**
     * 电话
     */
    private String phone;

    /**
     * 姓名
     */
    private String name;

    /**
     * 备注
     */
    private String msg;

    /**
     * 性别
     */
    private String gender;

    /**
     * 行政区划
     */
    private AdministrativeArea administrativeArea;

    /**
     * 分配的人员
     */
    @DBRef
    private User user;

    /**
     * 项目
     */
    @DBRef
    private Project project;

    /**
     * 调查对象状态
     */
    private String state;
}
