package com.example.survey.entity.inner;

import com.example.survey.entity.User;
import com.example.survey.enumeration.OpTypeEnum;
import lombok.*;
import org.springframework.data.mongodb.core.mapping.DBRef;

import java.util.Date;

/**
 * @author Pope
 * 操作信息
 */
@Data
public class Operation {

    /**
     * 操作
     */
    private String type;

    /**
     * 时间
     */
    private Date time;

    /**
     * 操作者
     */
    @DBRef
    private User user;

    /**
     * 版本信息
     */
    private String version;

    /**
     * 备注
     */
    private String msg;

    /**
     * 操作结果
     */
    private String result;


    public static Operation submitOp(User user, String msg, String version) {
        Operation submit = new Operation();
        submit.setType(OpTypeEnum.SUBMIT.getValue());
        submit.setTime(new Date());
        submit.setUser(user);
        submit.setVersion(version);
        submit.setMsg(msg);
        submit.setResult("提交成功");
        return submit;
    }

    public static Operation modifyOp(User user, String msg, String version) {
        Operation modify = new Operation();
        modify.setType(OpTypeEnum.MODIFY.getValue());
        modify.setTime(new Date());
        modify.setUser(user);
        modify.setVersion(version);
        modify.setMsg(msg);
        modify.setResult("提交修改");
        return modify;
    }

    public static Operation deleteOp(User user, String msg, String version) {
        Operation delete = new Operation();
        delete.setType(OpTypeEnum.DELETE.getValue());
        delete.setTime(new Date());
        delete.setUser(user);
        delete.setVersion(version);
        delete.setMsg(msg);
        delete.setResult("删除成功");
        return delete;
    }

    public static Operation reviewOp(User user, String msg, String version, boolean result) {
        Operation review = new Operation();
        review.setType(OpTypeEnum.REVIEW.getValue());
        review.setTime(new Date());
        review.setUser(user);
        review.setVersion(version);
        review.setMsg(msg);
        if (result) {
            review.setResult("审核通过");
        } else {
            review.setResult("审核不通过");
        }
        return review;
    }

    public static Operation coverOp(User user, String version) {
        Operation cover = new Operation();
        cover.setType(OpTypeEnum.COVER.getValue());
        cover.setTime(new Date());
        cover.setUser(user);
        cover.setVersion(version);
        cover.setMsg("因重复提交覆盖");
        cover.setResult("被覆盖");
        return cover;
    }
}
