package com.example.survey.service;

import com.example.survey.dto.project.CreateProjectDTO;
import com.example.survey.dto.project.ModifyProjectDTO;
import com.example.survey.dto.project.ModifyStateDTO;
import com.example.survey.vo.ProjectVO;

import java.util.List;

/**
 * @author Pope
 */
public interface ProjectService {


    /**
     * 创建新项目
     *
     * @param createProjectDTO 创建项目信息
     */
    void createProject(CreateProjectDTO createProjectDTO);


    /**
     * 根据筛选条件分页查询项目
     *
     * @param name        项目名
     * @param state       状态
     * @param currentPage 当前页数
     * @param pageSize    页大小
     * @return 项目vo
     */
    List<ProjectVO> listProjectLimit(String name, String state, int currentPage, int pageSize);

    /**
     * 根据项目名查询调查对象数量
     *
     * @param name 项目名
     * @return 调查对象数量
     */
    long countRespondent(String name);

    /**
     * 根据项目名与调查对象状态查询调查对象数量
     *
     * @param name            项目名
     * @param respondentState 调查对象状态
     * @return 调查对象数量
     */
    long countRespondent(String name, String respondentState);

    /**
     * 修改项目状态
     *
     * @param modifyStateDTO 修改信息
     */
    void modifyProjectState(ModifyStateDTO modifyStateDTO);

    /**
     * 修改项目数据
     *
     * @param modifyProjectDTO 修改信息
     */
    void modifyProject(ModifyProjectDTO modifyProjectDTO);

    /**
     * 根据项目吗查询数量
     *
     * @param name  项目名
     * @param state 项目状态
     * @return 数量
     */
    long countProject(String name, String state);
}
