package com.example.survey.service;

import com.example.survey.dto.respondent.*;
import com.example.survey.vo.RespondentVO;

import java.util.List;

/**
 * @author Pope
 */
public interface RespondentService {
    /**
     * 创建待调查对象
     *
     * @param createRespondentDTO 待调查对象信息
     * @return 是否创建成功
     */
    void createRespondent(CreateRespondentDTO createRespondentDTO);

    /**
     * 根据流调人员电话号码分页查询待调查对象数据
     *
     * @param userPhone   分配的人员电话号码
     * @param state       状态
     * @param idNumber    身份证号
     * @param name        调查对象姓名
     * @param phone       调查对象电话
     * @param province    省份
     * @param city        城市
     * @param county      区县
     * @param projectName 项目名
     * @param currentPage 当前页数
     * @param pageSize    页大小
     * @return 页数据
     */
    List<RespondentVO> listRespondentLimit(String userPhone, String state, String idNumber, String name, String phone, String province, String city, String county, String projectName, int currentPage, int pageSize);

    /**
     * 根据筛选条件查询调查对象数量
     *
     * @param userPhone   分配的人员电话号码
     * @param state       状态
     * @param idNumber    身份证号
     * @param name        调查对象姓名
     * @param phone       调查对象电话
     * @param province    省份
     * @param city        城市
     * @param county      区县
     * @param projectName 项目名
     * @return 数量
     */
    long countRespondent(String userPhone, String state, String idNumber, String name, String phone, String province, String city, String county, String projectName);

    /**
     * 修改调查对象信息
     *
     * @param modifyRespondentDTO 修改信息
     */
    void modifyRespondent(ModifyRespondentDTO modifyRespondentDTO);

    /**
     * 分配人员
     *
     * @param modifyRespondentUserDTO 绑定用户信息
     */
    void modifyUser(ModifyRespondentUserDTO modifyRespondentUserDTO);

    /**
     * 删除调查对象
     *
     * @param deleteRespondentDTO 删除信息
     */
    void deleteRespondent(DeleteRespondentDTO deleteRespondentDTO);
}
